* Output options - no page number, date, centering, page breaks or default titles; 
	OPTIONS nonumber nodate nocenter formdlim=' ' pagesize=MAX linesize=120; TITLE;

* Name folder to store permanent SAS datasets in;
	%LET filepath= C:\Users\Attention\Dropbox\Papers and Data\_Publications\MLM_for_Exp_Appendices;
* Create permanent SAS library;
	LIBNAME filepath "&filepath.";
* Name folders with SPSS portable files to import - note SPSS keyword;
	LIBNAME ImportP SPSS "&filepath.\Ex1_P.por"; 
	LIBNAME ImportI SPSS "&filepath.\Ex1_I.por";

* Define new temporary SAS dataset in work library called 'Ex1_P';
* Read in SPSS portable file from 'ImportP' called MLM_Ex1;
DATA work.Ex1_P; SET ImportP.Ex1_P; run;

* Tranposing response variables into single variable;
* Save tranposed dataset in work library called 'Ex1_PT';
PROC TRANSPOSE DATA=work.Ex1_P OUT=work.Ex1_PT;
	* BY gives variables to be transposed by;
	* VAR gives list of variables to be tranposed;
		BY ID Age Sex; VAR rt_sec1 -- rt_sec80; run;

* Variable transformation in transposed dataset;
* Re-opening work.Ex1_PT data, rename transposed outcome variable;
DATA work.Ex1_PT (RENAME= (Col1=rt_sec)); SET work.Ex1_PT;
	* Extracting item number from transposed column for name '_NAME_':
        Start at character 7, take 2 values, format with two digits;
		Item = INPUT(SUBSTR(_NAME_, 7, 2), 2.);
	* Drop non-needed variables;
		DROP _NAME_ _LABEL_; run;

* Define new temporary SAS dataset in work library called 'Ex1_I';
* Read in SPSS portable file from 'ImportI' called Ex1_I;
DATA work.Ex1_I; SET ImportI.Ex1_I; run;

* Sorting transposed person and item datasets prior to merging;
PROC SORT DATA=work.Ex1_PT; BY Item; run;
PROC SORT DATA=work.Ex1_I;  BY Item; run;

* Merging transposed person and item datasets by Item;
DATA work.Ex1; MERGE work.Ex1_PT work.Ex1_I; BY Item;
	* Creating natural log transform of RT;
		lg_rt = LOG(rt_sec);
	* Recoding age into two variables (missing, younger, older);
	* older will be treated as categorical in the models;
		IF age=. THEN oldage=.;
			ELSE IF age LE 40 THEN DO; oldage=0; older=0; END;
			ELSE IF age GT 40 THEN DO; oldage=1; older=1; END;
		IF oldage=. THEN yrs65=.;
			ELSE IF oldage=0 THEN yrs65=0; 
			ELSE IF oldage=1 THEN yrs65=age-65;
	* Centering meaning at midpoint;
		c_mean = meaning - 3;
	* Centering salience at midpoint;
		c_sal = salience - 3; 
	* Labeling new variables;
		LABEL rt_sec= 'Response Time in Seconds'
			  lg_rt=  'Natural Log RT in Seconds'
		  	  oldage= 'Over Age 40 (0=no, 1=yes)'
			  older=  'Copy of oldage to be treated as categorical'
		  	  yrs65=  'Years Over Age 65 (0=65)'
		  	  c_mean= 'Centered Meaning (0=3)'
		  	  c_sal=  'Centered Salience (0=3)'; 
run;

* Save final file for analysis;
DATA filepath.Ex1; SET work.Ex1; RUN;

/* PROC MIXED syntax commands used below:

DATA gives file used for analysis
COVTEST gives significance tests of covariance parameters
NOCLPRINT suppresses class variable list
NOITPRINT suppresses iteration history print
METHOD=ML specifies maximum likelihood (default is restricted ML)
CLASS defines categorical variables
MODEL defines equation, where [outcome] = [predictors]
	/ SOLUTION asks for parameter estimates
	  DDFM=Satterthwaite specifies Satterthwaite degrees of freedom
RANDOM lists random effects 
	/ SUBJECT=ID defines nesting structure for level 2 persons
	/ SUBJECT=Item defines nesting structure for level 2 items
	  TYPE=UN specifies unstructured matrix (all variances & covariances)
REPEATED allows structuring of the residual variance
	  GROUP=older indicates separate variances for each level of older */ 

/* Example 1 Multilevel Models */

* Save results to a permanent file;
ODS HTML FILE="&filepath./SAS Results for Example 1.html" STYLE=HTMLBLUE;

TITLE 'SAS Model 1.1: Empty Model with Homogeneous Errors';
PROC MIXED DATA=work.Ex1 COVTEST NOCLPRINT IC NAMELEN=100 METHOD=ML;
	CLASS ID Item;
	MODEL lg_rt = / SOLUTION DDFM=Satterthwaite; 
	RANDOM INTERCEPT / SUBJECT=Item TYPE=UN;
	RANDOM INTERCEPT / SUBJECT=ID TYPE=UN;
	REPEATED / SUBJECT=ID TYPE=VC; run;

TITLE 'SAS Model 1.2a: Main Effects Model with Homogeneous Errors';
PROC MIXED DATA=work.Ex1 COVTEST NOCLPRINT IC NAMELEN=100 METHOD=ML;
	CLASS ID Item older;
	MODEL lg_rt = c_mean c_sal oldage yrs65/ SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT / SUBJECT=Item TYPE=UN;
	RANDOM INTERCEPT / SUBJECT=ID TYPE=UN;
	REPEATED / SUBJECT=ID TYPE=VC; run;

TITLE 'SAS Model 1.2b: Main Effects Model with Heterogeneous Errors';
PROC MIXED DATA=work.Ex1 COVTEST NOCLPRINT IC NAMELEN=100 METHOD=ML;
	CLASS ID Item older;
	MODEL lg_rt = c_mean c_sal oldage yrs65 / SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT / SUBJECT=Item TYPE=UN;
	RANDOM INTERCEPT / SUBJECT=ID TYPE=UN GROUP=older;
	REPEATED / SUBJECT=ID TYPE=VC GROUP=older; run;

TITLE 'SAS Model 1.3a: All Two-Way and Three-Way Interactions';
PROC MIXED DATA=work.Ex1 COVTEST NOCLPRINT IC NAMELEN=100 METHOD=ML;
	CLASS ID Item older;
	MODEL lg_rt = c_mean c_sal oldage yrs65 c_mean*c_sal 
				  c_mean*oldage c_mean*yrs65 c_sal*oldage c_sal*yrs65
				  c_mean*c_sal*oldage c_mean*c_sal*yrs65 
		/ SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT / SUBJECT=Item TYPE=UN;
	RANDOM INTERCEPT / SUBJECT=ID TYPE=UN GROUP=older;
	REPEATED / SUBJECT=ID TYPE=VC GROUP=older; run;

TITLE 'SAS revised Model 1.3b: Significant Interactions Only';
PROC MIXED DATA=work.Ex1 COVTEST NOCLPRINT IC NAMELEN=100 METHOD=ML;
	CLASS ID Item older;
	MODEL lg_rt = c_mean c_sal oldage yrs65 c_mean*c_sal 
				  c_mean*oldage c_sal*oldage
				  c_mean*c_sal*oldage / SOLUTION DDFM=Satterthwaite;
	RANDOM INTERCEPT / SUBJECT=Item TYPE=UN;
	RANDOM INTERCEPT / SUBJECT=ID TYPE=UN GROUP=older;
	REPEATED / SUBJECT=ID TYPE=VC GROUP=older; run;

* Close permanent file, reopen HTML output window;
ODS HTML CLOSE; ODS HTML;

/******* Importing 'fake' people to make trajectories for ******/

* Sort original datafile by ID variables for merging;
PROC SORT DATA=work.Ex1; BY ID; RUN;
* Importing fake people data from excel;	
PROC IMPORT DATAFILE = "&filepath.\Plots_Ex1.xls"
	OUT=work.Plots DBMS=EXCEL REPLACE; GETNAMES=YES; RUN;
* Sort fake people by ID variables for merging;
PROC SORT DATA=work.Plots; BY ID; RUN;
* Merging original datafile and fake people for prediction;
DATA work.Merged; MERGE work.Ex1 work.Plots; BY ID; RUN;
* Running final model to get predicted values;
PROC MIXED DATA=work.Merged COVTEST NOCLPRINT NOITPRINT METHOD=ML;
	CLASS ID Item older;
	MODEL lg_rt = c_mean c_sal oldage yrs65 c_mean*c_sal 
				  c_mean*oldage c_sal*oldage
				  c_mean*c_sal*oldage / SOLUTION DDFM=Satterth OUTPM=Plots;
	RANDOM INTERCEPT / SUBJECT=Item TYPE=UN;
	RANDOM INTERCEPT / SUBJECT=ID TYPE=UN GROUP=older;
	REPEATED /SUBJECT=ID TYPE=VC GROUP=older; run;

* Renaming predicted outcome, keeping only fake people;
DATA work.Plots (RENAME=(pred=pred_rt)); SET work.Plots; WHERE ID > 900; run;
PROC SORT DATA=work.Plots; BY ID; run;

/* Color Figure */

* Setting generic plotting options for text, size, and joining lines;
GOPTIONS NOBORDER FTEXT=Triplex FTITLE=Triplex VSIZE=4.5in HSIZE=6in INTERPOL=JOIN
GSFNAME=outgraph DEV=BMP GSFMODE=replace; run;

TITLE1; TITLE2;
FILENAME outgraph "&filepath.\Ex1.bmp";
PROC GPLOT DATA=work.Plots; 
	 * Settings for Y-axis;
	 AXIS1 LABEL=(HEIGHT=1.3 ANGLE=90 "Natural Log RT in Seconds") LENGTH=3.0in ORDER=(0 TO 3 BY .5);
	 * Settings for X-axis;
	 AXIS2 LABEL=(HEIGHT=1.3 "Change Salience") LENGTH=5.0in ORDER=(0 TO 5 BY 1);
	 * Setting for legend - place at top, no frame around it, 2 values across;
	 * Labels for series in order of ID;
	 LEGEND1 NOFRAME POSITION=(CENTER TOP) ACROSS=2 LABEL=NONE VALUE=(HEIGHT=1.2 COLOR=Black 
		"Age 80, Low Meaning" "Age 80, High Meaning"
		"Age 65, Low Meaning" "Age 65, High Meaning"
		"Younger, Low Meaning" "Younger, High Meaning") ;
	 SYMBOL1 COLOR=Blue  VALUE=Square    HEIGHT=1.4 LINE=1 WIDTH=2;
	 SYMBOL2 COLOR=Blue  VALUE=Square    HEIGHT=1.4 LINE=4 WIDTH=2;
	 SYMBOL3 COLOR=Green VALUE=Triangle  HEIGHT=1.4 LINE=1 WIDTH=2;
	 SYMBOL4 COLOR=Green VALUE=Triangle  HEIGHT=1.4 LINE=4 WIDTH=2;
	 SYMBOL5 COLOR=Red   VALUE=Circle    HEIGHT=1.4 LINE=1 WIDTH=2;
	 SYMBOL6 COLOR=Red   VALUE=Circle    HEIGHT=1.4 LINE=4 WIDTH=2;
	 PLOT pred_rt*salience=ID / VAXIS=AXIS1 HAXIS=AXIS2 LEGEND=LEGEND1;  
RUN; QUIT;

/* Black and White Figure */

TITLE1; TITLE2;
FILENAME outgraph "&filepath.\Ex1 BW.bmp";
PROC GPLOT DATA=work.Plots; 
	 * Settings for Y-axis;
	 AXIS1 LABEL=(HEIGHT=1.3 ANGLE=90 "Natural Log RT in Seconds") LENGTH=3.0in ORDER=(0 TO 3 BY .5);
	 * Settings for X-axis;
	 AXIS2 LABEL=(HEIGHT=1.3 "Change Salience") LENGTH=5.0in ORDER=(0 TO 5 BY 1);
	 * Setting for legend - place at top, no frame around it, 2 values across;
	 * Labels for series in order of ID;
	 LEGEND1 NOFRAME POSITION=(CENTER TOP) ACROSS=2 LABEL=NONE VALUE=(HEIGHT=1.2 COLOR=Black 
		"Age 80, Low Meaning" "Age 80, High Meaning"
		"Age 65, Low Meaning" "Age 65, High Meaning"
		"Younger, Low Meaning" "Younger, High Meaning") ;
	 SYMBOL1 COLOR=Black VALUE=Square    HEIGHT=1.4 LINE=1 WIDTH=2;
	 SYMBOL2 COLOR=Black VALUE=Square    HEIGHT=1.4 LINE=4 WIDTH=2;
	 SYMBOL3 COLOR=Black VALUE=Triangle  HEIGHT=1.4 LINE=1 WIDTH=2;
	 SYMBOL4 COLOR=Black VALUE=Triangle  HEIGHT=1.4 LINE=4 WIDTH=2;
	 SYMBOL5 COLOR=Black VALUE=Circle    HEIGHT=1.4 LINE=1 WIDTH=2;
	 SYMBOL6 COLOR=Black VALUE=Circle    HEIGHT=1.4 LINE=4 WIDTH=2;
	 PLOT pred_rt*salience=ID / VAXIS=AXIS1 HAXIS=AXIS2 LEGEND=LEGEND1;  
RUN; QUIT;



