* Define location for files.
  FILE HANDLE filepath NAME = "F:\Papers and Data\_Publications\MLM_for_Exp_Appendices".

* Define new SPSS dataset called 'Ex1_P'.
	 IMPORT FILE =  'filepath/Ex1_P.por'.
	 DATASET NAME Ex1_P WINDOW=FRONT.

* Transposing response variables into single variable.
  VARSTOCASES  
	  /MAKE rt_sec FROM rt_sec1 TO rt_sec80
	  /INDEX = NAME(rt_sec)
   /KEEP = ALL
	  /NULL = KEEP.
* Extracting item number from transposed for name 'NAME':
  Start at character 7, take 2 values, format with two digits.
 	COMPUTE Item = NUMBER((SUBSTR(NAME, 7, 2)), F2). 
* Sorting tranposed person dataset prior to merging.
	 SORT CASES BY Item.
* Rename file.
  DATASET NAME Ex1_PT WINDOW=FRONT.

* Define new SPSS dataset called 'Ex1_I', sort by Item.
	 IMPORT FILE = 'filepath\Ex1_I.por'.
  DATASET NAME Ex1_I WINDOW=FRONT.
	 SORT CASES BY Item.
	
* Merging transposed person and item datasets by Item.
	 MATCH FILES
		 /FILE =  'Ex1_PT'
		 /TABLE = 'Ex1_I'
		 /BY Item.
* Creating natural log transform of RT.
 	COMPUTE lg_rt = LN(rt_sec).
* Recoding age into two variables (younger, older).
	 IF (age LE 40) oldage = 0.
	 IF (age GT 40) oldage = 1.
* Make new variable for old age to be treated as categorical.
  COMPUTE older = oldage.
* Create slope for older group.
	 IF (oldage EQ 0) yrs65 = 0.
	 IF (oldage EQ 1) yrs65 = age - 65.
* Centering meaning at midpoint.
	 COMPUTE c_mean = meaning - 3.
* Centering salience at midpoint.
	 COMPUTE c_sal = salience - 3.
* Labeling new variables.
	 VARIABLE LABELS 
       rt_sec 'Response Time in Seconds'
			    lg_rt  'Natural Log RT in Seconds'
			    oldage 'Over Age 40 (0=no, 1=yes)'
       older  'Copy of oldage to be treated as categorical'
			    yrs65  'Years Over Age 65 (0=65)'
			    c_mean 'Centered Meaning (0=3)'
			    c_sal  'Centered Salience (0=3)'.
* Rename and save file.
	 DATASET NAME Ex1 WINDOW=FRONT.
  SAVE OUTFILE = 'filepath\Ex1.sav'.

* MIXED syntax commands used below:
MIXED defines outcome 
BY defines categorical variables, WITH defines continuous variables
FIXED defines fixed effects
METHOD=ML specifies maximum likelihood (default is restricted ML)
PRINT=SOLUTION asks for parameter estimates
PRINT=TESTCOV gives significance tests of covariance parameters
RANDOM lists random effects
	/ SUBJECT(ID) defines nesting structure for level 2 persons
	/ SUBJECT (Item) defines nesting structure for level 2 items
	  COVTYPE(UN) specifies unstructured matrix (all variances & covariances).

* ORIGINAL HOFFMAN & ROVINE (2007) SYNTAX: Example 1 Multilevel Models.

DATASET ACTIVATE Ex1 WINDOW=FRONT.

TITLE 'SPSS Model 1.1: Empty Model'.
MIXED lg_rt BY ID Item
  	/FIXED  =
  	/METHOD = ML
  	/PRINT  = SOLUTION TESTCOV
	  /RANDOM = INTERCEPT | SUBJECT(Item) COVTYPE(UN)
 	 /RANDOM = INTERCEPT | SUBJECT(ID) COVTYPE(UN).

TITLE 'SPSS Model 1.2a: Main Effects Model with Homogeneous Errors'.
MIXED lg_rt BY ID Item WITH c_mean c_sal oldage yrs65
  	/FIXED  = c_mean c_sal oldage yrs65
  	/METHOD = ML
  	/PRINT  = SOLUTION TESTCOV
	  /RANDOM = INTERCEPT | SUBJECT(Item) COVTYPE(UN)
 	 /RANDOM = INTERCEPT | SUBJECT(ID) COVTYPE(UN).

/* NOTE  SPSS will not allow heterogeneous errors -- SEE BELOW! */

TITLE 'SPSS Model 1.3a: All Two-Way and Three-Way Interaction'.
MIXED lg_rt BY ID Item WITH c_mean c_sal oldage yrs65
  	/FIXED  = c_mean c_sal oldage yrs65 c_mean*c_sal
		           c_mean*oldage c_mean*yrs65 c_sal*oldage c_sal*yrs65
		           c_mean*c_sal*oldage c_mean*c_sal*yrs65
  	/METHOD = ML
  	/PRINT  = SOLUTION TESTCOV
	  /RANDOM = INTERCEPT | SUBJECT(Item) COVTYPE(UN)
 	 /RANDOM = INTERCEPT | SUBJECT(ID) COVTYPE(UN).

TITLE 'SPSS revised Model 1.3b: Significant Interactions Only'.
MIXED lg_rt BY ID Item WITH c_mean c_sal oldage yrs65
  	/FIXED  = c_mean c_sal oldage yrs65 c_mean*c_sal
		           c_mean*oldage c_sal*oldage
		           c_mean*c_sal*oldage 
  	/METHOD = ML
  	/PRINT  = SOLUTION TESTCOV
	  /RANDOM = INTERCEPT | SUBJECT(Item) COVTYPE(UN)
 	 /RANDOM = INTERCEPT | SUBJECT(ID) COVTYPE(UN).


* NEW SYNTAX BASED ON WEAVER & BLACK (2014) TO ADD HETEROGENEOUS VARIANCES BY OLDAGE.

TITLE 'SPSS Model 1.2b: Main Effects Model with Heterogeneous Errors'.
MIXED lg_rt BY ID Item older WITH c_mean c_sal oldage yrs65
  	/FIXED  = c_mean c_sal oldage yrs65
  	/METHOD = ML
  	/PRINT  = SOLUTION TESTCOV
	  /RANDOM = INTERCEPT | SUBJECT(Item) COVTYPE(UN)
 	 /RANDOM = older | SUBJECT(ID) COVTYPE(DIAG)
   /REPEATED = older | SUBJECT(ID*Item) COVTYPE(DIAG).

TITLE 'SPSS revised Model 1.3b: Significant Interactions Only'.
MIXED lg_rt BY ID Item older WITH c_mean c_sal oldage yrs65
  	/FIXED  = c_mean c_sal oldage yrs65 c_mean*c_sal
		           c_mean*oldage c_sal*oldage
		           c_mean*c_sal*oldage
  	/METHOD = ML
  	/PRINT  = SOLUTION TESTCOV
	  /RANDOM = INTERCEPT | SUBJECT(Item) COVTYPE(UN)
 	 /RANDOM = older | SUBJECT(ID) COVTYPE(DIAG)
   /REPEATED = older | SUBJECT(ID*Item) COVTYPE(DIAG).



