* Output options - no page number, date, centering, page breaks or default titles; 
	OPTIONS nonumber nodate nocenter formdlim=' ' pagesize=MAX linesize=120; TITLE;

* Name folder to store permanent SAS datasets in;
	%LET filepath= F:\Papers and Data\_Publications\MLM_for_Exp_Appendices;
* Create permanent SAS library;
	LIBNAME filepath "&filepath.";
* Name folders with SPSS portable files to import - note SPSS keyword;
	LIBNAME Import2 SPSS "&filepath.\Ex2.por";

* Define new SAS dataset in 'Example' library called 'Ex2_1';
DATA work.Ex2_1; 
	* Read in SPSS portable file from 'Import2' called Ex2;
		SET Import2.Ex2;
	* Stacking variables for univariate analysis;
	* OUTPUT writes a new line of data with these variables;
		rt_ms=rt_ms_L3; p_err=p_err_L3; target=1; setsize=3; OUTPUT;
		rt_ms=rt_ms_L6; p_err=p_err_L6; target=1; setsize=6; OUTPUT;
		rt_ms=rt_ms_L9; p_err=p_err_L9; target=1; setsize=9; OUTPUT;
		rt_ms=rt_ms_R3; p_err=p_err_R3; target=2; setsize=3; OUTPUT;
		rt_ms=rt_ms_R6; p_err=p_err_R6; target=2; setsize=6; OUTPUT;
		rt_ms=rt_ms_R9; p_err=p_err_R9; target=2; setsize=9; OUTPUT;
	* Labeling new variables;
		LABEL rt_ms=   "RT in Milliseconds"
		  	  p_err=   "Percent Errors"
		      target=  "Target Letter (1=L, 2=R)"
		      setsize= "Number of Distractors (3,6,9)";
	* Dropping old condition responses;
		DROP rt_ms_L3 -- p_err_R9;  run;

* Variable transformation in stacked dataset;
* Re-opening Example.Ex2_1 data;
DATA work.Ex2_1; SET work.Ex2_1;
	* Creating natural log transform of RT;
		lg_rt = LOG(rt_ms);
	* Creating z-scored version of log RT and errors;
		z_lg_rt = (lg_rt - 6.7317470) / 0.2412115;
		z_p_err = (p_err - 0.1719970) / 0.1486222;
	* Centering age at 75;
		c_age = age - 75;
	* Centering setsize at 6;
		c_size = setsize - 6;
	* Centering target letter;
		c_targ = target - 1;
	* Labeling new variables;
		LABEL lg_rt='Natural Log RT in Milliseconds'
		      z_lg_rt="Z-Scored Natural Log RT in Milliseconds"
		      z_p_err="Z-Scored Percent Errors"
		      c_age="Centered Age (0=75)"
		      c_size="Centered Set Size (0=6)"
		      c_targ="Centered Target Letter (0=L, 1=R)";  run;

* Creating double-stacked dataset for multivariate analysis;
* Define new SAS dataset in 'Example' library called 'Ex2_2';
DATA work.Ex2_2; 
	* Create new dataset from Example.Ex2_1;
		SET work.Ex2_1;
	* Stacking response time and errors into a single variable;
		y_raw=lg_rt; y_SD=z_lg_rt; dv=1; dv1=1; dv2=0; OUTPUT;
		y_raw=p_err; y_SD=z_p_err; dv=2; dv1=0; dv2=1; OUTPUT;
	* Labeling new variables;
		LABEL y_raw="Raw-Score Multivariate Outcome"
		  	  y_SD="Z-Score Multivariate Outcome"
		      dv="Which Outcome Variable (1=RT, 2=Error)"
		      dv1="Response Time (0=no, 1=yes)"
		      dv2="Percent Error (0=no, 1=yes)";   run;

* Save final file for analysis;
DATA filepath.Ex2_2; SET work.Ex2_2; RUN;

/* Additional PROC MIXED syntax commands used below:

CLASS defines categorical variables (nesting variables and DV)
MODEL defines equation, where [outcome] = [predictors]
	/ SOLUTION asks for parameter estimates
	  DDFM=Satterthwaite specifies Satterthwaite degrees of freedom
	  NOINT removes intercept (when using dv1 and dv2 instead)
RANDOM lists random effects 
	/ SUBJECT=ID defines nesting structure for level 3
	  TYPE=UN specifies unstructured matrix (all variances & 
                covariances of random effects) 
	  GCORR asks for the G random effects matrix in correlation form
REPEATED lists repeated effects
	/ SUBJECT=target*setsize*ID defines nesting structure for level 2
	  TYPE=UN specifies unstructured matrix (all variances and 
                covariances of residuals)
	  RCORR asks for the R residual matrix in correlation form */ 

/* Example 2 Multivariate Multilevel Models */

* Save results to a permanent file;
ODS HTML FILE="&filepath./SAS Results for Example 2.html" STYLE=HTMLBLUE;

TITLE 'SAS Model 2.1: Empty Model';
PROC MIXED DATA=work.Ex2_2 COVTEST NOCLPRINT NOITPRINT METHOD=ML;
	CLASS ID target setsize DV;
	MODEL y_raw =  dv1 dv2 / NOINT SOLUTION DDFM=Satterthwaite;
	RANDOM dv1 dv2 / SUBJECT=ID TYPE=UN GCORR; 
	REPEATED DV / SUBJECT=target*setsize*ID TYPE=UN RCORR; run;

TITLE 'SAS Model 2.2: Main Effects Model';
PROC MIXED DATA=work.Ex2_2 COVTEST NOCLPRINT NOITPRINT METHOD=ML;
	CLASS ID target setsize DV;
	MODEL y_raw = dv1 dv1*c_size dv1*c_targ dv1*c_age 
			      dv2 dv2*c_size dv2*c_targ dv2*c_age 
				/ NOINT SOLUTION DDFM=Satterthwaite;
	RANDOM dv1 dv2 dv1*c_size dv2*c_size dv1*c_targ dv2*c_targ 
				/ SUBJECT=ID TYPE=UN GCORR; 
	REPEATED DV / SUBJECT=target*setsize*ID TYPE=UN RCORR; run;

TITLE 'SAS Model 2.3a: All Interactions Model';
PROC MIXED DATA=work.Ex2_2 COVTEST NOCLPRINT NOITPRINT METHOD=ML;
	CLASS ID target setsize DV;
	MODEL y_raw = dv1 dv1*c_size dv1*c_targ dv1*c_age 
			      dv1*c_size*c_targ dv1*c_age*c_size dv1*c_age*c_targ 
				  dv1*c_age*c_targ*c_size
			      dv2 dv2*c_size dv2*c_targ dv2*c_age 
 			      dv2*c_size*c_targ dv2*c_age*c_size dv2*c_age*c_targ 
				  dv2*c_age*c_targ*c_size
				/ NOINT SOLUTION DDFM=Satterthwaite;
	RANDOM dv1 dv2 dv1*c_size dv2*c_size dv1*c_targ dv2*c_targ 
				/ SUBJECT=ID TYPE=UN GCORR; 
	REPEATED DV / SUBJECT=target*setsize*ID TYPE=UN RCORR; run;

TITLE 'SAS revised Model 2.3b: Significant Interactions Only Model';
PROC MIXED DATA=work.Ex2_2 COVTEST NOCLPRINT NOITPRINT METHOD=ML;
	CLASS ID target setsize DV;
	MODEL y_raw = dv1 dv1*c_size dv1*c_targ dv1*c_age 
				  dv1*c_size*c_targ dv1*c_age*c_size  
			      dv2 dv2*c_size dv2*c_targ dv2*c_age  
				/ NOINT SOLUTION DDFM=Satterthwaite;
	RANDOM dv1 dv2 dv1*c_size dv2*c_size dv1*c_targ dv2*c_targ 
				/ SUBJECT=ID TYPE=UN GCORR; 
	REPEATED DV / SUBJECT=target*setsize*ID TYPE=UN RCORR; run;

TITLE 'SAS Re-Parameterized Model 2.4: Standardized Response Variables';
PROC MIXED DATA=work.Ex2_2 COVTEST NOCLPRINT NOITPRINT METHOD=ML;
	CLASS ID target setsize DV;
	MODEL y_SD = c_size c_targ c_age c_size*c_targ c_age*c_size 
			     dv2 dv2*c_size dv2*c_targ dv2*c_age 
			     dv2*c_size*c_targ dv2*c_age*c_size 
				/ SOLUTION DDFM=Satterthwaite;
	RANDOM dv1 dv2 dv1*c_size dv2*c_size dv1*c_targ dv2*c_targ 
				/ SUBJECT=ID TYPE=UN GCORR; 
	REPEATED DV / SUBJECT=target*setsize*ID TYPE=UN RCORR; run;

* Close permanent file, reopen HTML output window;
ODS HTML CLOSE; ODS HTML;

/******* Importing 'fake' people to make trajectories for ******/

* Sort original datafile by ID variables for merging;
PROC SORT DATA=work.Ex2_2; BY ID; RUN;
* Importing fake people data from excel;	
PROC IMPORT DATAFILE = "&filepath.\Plots_Ex2.xls"
	OUT=work.Plots DBMS=EXCEL REPLACE; GETNAMES=YES; RUN;
* Sort fake people by ID variables for merging;
PROC SORT DATA=work.Plots; BY ID; RUN;
* Merging original datafile and fake people for prediction;
DATA work.Merged; MERGE work.Ex2_2 work.Plots; BY ID; RUN;
* Running final model to get predicted values;
PROC MIXED DATA=work.Merged COVTEST NOCLPRINT NOITPRINT METHOD=ML;
	CLASS ID DV setsize target;
	MODEL y_raw =  dv1 dv1*c_size dv1*c_targ dv1*c_size*c_targ dv1*c_age dv1*c_age*c_size  
			       dv2 dv2*c_size dv2*c_targ 				   dv2*c_age  
		/ NOINT SOLUTION DDFM=Satterthwaite OUTPM=work.Plots;
	RANDOM dv1 dv2 dv1*c_size dv2*c_size dv1*c_targ dv2*c_targ / GCORR SUBJECT=ID TYPE=UN; 
	REPEATED DV / RCORR SUBJECT=target*setsize*ID TYPE=UN; run;

* Renaming predicted outcome, keeping only fake people;
DATA work.Plots (RENAME=(pred=pred_rt)); SET work.Plots; WHERE ID > 900; run;
PROC SORT DATA=work.Plots; BY ID setsize c_size target c_targ DESCENDING age c_age; run;


/* Color Figures */

* Setting generic plotting options for text, size, and joining lines;
GOPTIONS NOBORDER FTEXT=Triplex FTITLE=Triplex VSIZE=4.5in HSIZE=6in INTERPOL=JOIN
GSFNAME=outgraph DEV=BMP GSFMODE=replace; run;

TITLE1; TITLE2;
FILENAME outgraph "&filepath.\Ex2a.bmp";
PROC GPLOT DATA=work.Plots; WHERE DV=1;
	 * Settings for Y-axis for RT;
	 AXIS1 LABEL=(HEIGHT=1.3 ANGLE=90 "Natural Log RT in Milliseconds") LENGTH=3.0in ORDER=(6.25 TO 7.25 BY .25);
	 * Settings for Y-axis for Errors;
	 AXIS2 LABEL=(HEIGHT=1.3 "Set Size") LENGTH=5.0in ORDER=(2 TO 10 BY 1);
	 * Setting for legend - place at top, no frame around it, 2 values across;
	 * Labels for series in order of ID;
	 LEGEND1 NOFRAME POSITION=(CENTER TOP) ACROSS=2 LABEL=NONE VALUE=(HEIGHT=1.2 COLOR=Black 
		"Age 85, Target R" "Age 85, Target L"
		"Age 75, Target R" "Age 75, Target L"
		"Age 65, Target R" "Age 65, Target L") ;
	 SYMBOL1 COLOR=Blue  VALUE=Square    HEIGHT=1.4 LINE=1 WIDTH=2;
	 SYMBOL2 COLOR=Blue  VALUE=Square    HEIGHT=1.4 LINE=4 WIDTH=2;
	 SYMBOL3 COLOR=Green VALUE=Triangle  HEIGHT=1.4 LINE=1 WIDTH=2;
	 SYMBOL4 COLOR=Green VALUE=Triangle  HEIGHT=1.4 LINE=4 WIDTH=2;
	 SYMBOL5 COLOR=Red   VALUE=Circle    HEIGHT=1.4 LINE=1 WIDTH=2;
	 SYMBOL6 COLOR=Red   VALUE=Circle    HEIGHT=1.4 LINE=4 WIDTH=2;
	 PLOT  pred_rt*setsize=ID / VAXIS=AXIS1 HAXIS=AXIS2 LEGEND=LEGEND1; 
RUN; QUIT;

* Setting generic plotting options for text, size, and joining lines;
GOPTIONS NOBORDER FTEXT=Triplex FTITLE=Triplex VSIZE=4.5in HSIZE=6in INTERPOL=JOIN
GSFNAME=outgraph DEV=BMP GSFMODE=replace; run;

TITLE1; TITLE2;
FILENAME outgraph "&filepath.\Ex2b.bmp";
PROC GPLOT DATA=work.Plots; WHERE DV=2;
	 * Settings for Y-axis for Errors;
	 AXIS1 LABEL=(HEIGHT=1.3 ANGLE=90 "Proportion Error Rate") LENGTH=3.0in ORDER=(.0 TO .35 BY .05);
	 * Settings for X-axis;
	 AXIS2 LABEL=(HEIGHT=1.3 "Set Size") LENGTH=5.0in ORDER=(2 TO 10 BY 1);
	 * Setting for legend - place at top, no frame around it, 2 values across;
	 * Labels for series in order of ID;
	 LEGEND1 NOFRAME POSITION=(CENTER TOP) ACROSS=2 LABEL=NONE VALUE=(HEIGHT=1.2 COLOR=Black 
		"Age 85, Target R" "Age 85, Target L"
		"Age 75, Target R" "Age 75, Target L"
		"Age 65, Target R" "Age 65, Target L") ;
	 SYMBOL1 COLOR=Blue  VALUE=Square    HEIGHT=1.4 LINE=1 WIDTH=2;
	 SYMBOL2 COLOR=Blue  VALUE=Square    HEIGHT=1.4 LINE=4 WIDTH=2;
	 SYMBOL3 COLOR=Green VALUE=Triangle  HEIGHT=1.4 LINE=1 WIDTH=2;
	 SYMBOL4 COLOR=Green VALUE=Triangle  HEIGHT=1.4 LINE=4 WIDTH=2;
	 SYMBOL5 COLOR=Red   VALUE=Circle    HEIGHT=1.4 LINE=1 WIDTH=2;
	 SYMBOL6 COLOR=Red   VALUE=Circle    HEIGHT=1.4 LINE=4 WIDTH=2;
	 PLOT  pred_rt*setsize=ID / VAXIS=AXIS1 HAXIS=AXIS2 LEGEND=LEGEND1;
RUN; QUIT;


/* Black and White Figures */

* Setting generic plotting options for text, size, and joining lines;
GOPTIONS NOBORDER FTEXT=Triplex FTITLE=Triplex VSIZE=4.5in HSIZE=6in INTERPOL=JOIN
GSFNAME=outgraph DEV=BMP GSFMODE=replace; run;

TITLE1; TITLE2;
FILENAME outgraph "&filepath.\Ex2a BW.bmp";
PROC GPLOT DATA=work.Plots; WHERE DV=1;
	 * Settings for Y-axis for RT;
	 AXIS1 LABEL=(HEIGHT=1.3 ANGLE=90 "Natural Log RT in Milliseconds") LENGTH=3.0in ORDER=(6.25 TO 7.25 BY .25);
	 * Settings for Y-axis for Errors;
	 AXIS2 LABEL=(HEIGHT=1.3 "Set Size") LENGTH=5.0in ORDER=(2 TO 10 BY 1);
	 * Setting for legend - place at top, no frame around it, 2 values across;
	 * Labels for series in order of ID;
	 LEGEND1 NOFRAME POSITION=(CENTER TOP) ACROSS=2 LABEL=NONE VALUE=(HEIGHT=1.2 COLOR=Black 
		"Age 85, Target R" "Age 85, Target L"
		"Age 75, Target R" "Age 75, Target L"
		"Age 65, Target R" "Age 65, Target L") ;
	 SYMBOL1 COLOR=Black VALUE=Square    HEIGHT=1.4 LINE=1 WIDTH=2;
	 SYMBOL2 COLOR=Black VALUE=Square    HEIGHT=1.4 LINE=4 WIDTH=2;
	 SYMBOL3 COLOR=Black VALUE=Triangle  HEIGHT=1.4 LINE=1 WIDTH=2;
	 SYMBOL4 COLOR=Black VALUE=Triangle  HEIGHT=1.4 LINE=4 WIDTH=2;
	 SYMBOL5 COLOR=Black VALUE=Circle    HEIGHT=1.4 LINE=1 WIDTH=2;
	 SYMBOL6 COLOR=Black VALUE=Circle    HEIGHT=1.4 LINE=4 WIDTH=2;
	 PLOT  pred_rt*setsize=ID / VAXIS=AXIS1 HAXIS=AXIS2 LEGEND=LEGEND1; 
RUN; QUIT;

* Setting generic plotting options for text, size, and joining lines;
GOPTIONS NOBORDER FTEXT=Triplex FTITLE=Triplex VSIZE=4.5in HSIZE=6in INTERPOL=JOIN
GSFNAME=outgraph DEV=BMP GSFMODE=replace; run;

TITLE1; TITLE2;
FILENAME outgraph "&filepath.\Ex2b BW.bmp";
PROC GPLOT DATA=work.Plots; WHERE DV=2;
	 * Settings for Y-axis for Errors;
	 AXIS1 LABEL=(HEIGHT=1.3 ANGLE=90 "Proportion Error Rate") LENGTH=3.0in ORDER=(.0 TO .35 BY .05);
	 * Settings for X-axis;
	 AXIS2 LABEL=(HEIGHT=1.3 "Set Size") LENGTH=5.0in ORDER=(2 TO 10 BY 1);
	 * Setting for legend - place at top, no frame around it, 2 values across;
	 * Labels for series in order of ID;
	 LEGEND1 NOFRAME POSITION=(CENTER TOP) ACROSS=2 LABEL=NONE VALUE=(HEIGHT=1.2 COLOR=Black 
		"Age 85, Target R" "Age 85, Target L"
		"Age 75, Target R" "Age 75, Target L"
		"Age 65, Target R" "Age 65, Target L") ;
	 SYMBOL1 COLOR=Black VALUE=Square    HEIGHT=1.4 LINE=1 WIDTH=2;
	 SYMBOL2 COLOR=Black VALUE=Square    HEIGHT=1.4 LINE=4 WIDTH=2;
	 SYMBOL3 COLOR=Black VALUE=Triangle  HEIGHT=1.4 LINE=1 WIDTH=2;
	 SYMBOL4 COLOR=Black VALUE=Triangle  HEIGHT=1.4 LINE=4 WIDTH=2;
	 SYMBOL5 COLOR=Black VALUE=Circle    HEIGHT=1.4 LINE=1 WIDTH=2;
	 SYMBOL6 COLOR=Black VALUE=Circle    HEIGHT=1.4 LINE=4 WIDTH=2;
	 PLOT  pred_rt*setsize=ID / VAXIS=AXIS1 HAXIS=AXIS2 LEGEND=LEGEND1;
RUN; QUIT;

