* Define location for files.
  FILE HANDLE filepath NAME = "F:\Papers and Data\_Publications\MLM_for_Exp_Appendices".

* Define new SPSS dataset called 'Ex2_1'.
	 IMPORT FILE = 'filepath\Ex2.por'.
	 DATASET NAME Ex2_1 WINDOW=FRONT.

* Stacking variables for univariate analysis.
	VARSTOCASES  
		/MAKE rt_ms FROM rt_ms_l3 rt_ms_l6 rt_ms_l9 rt_ms_r3 rt_ms_r6 rt_ms_r9
 	/MAKE p_err FROM p_err_l3 p_err_l6 p_err_l9 p_err_r3 p_err_r6 p_err_r9
 	/INDEX = target  "Target Letter (1=L, 2=R)"(2) 
			        setsize "Number of Distractors (3,6,9)"(3)
 		/KEEP =  ALL 
	 	/NULL = KEEP.
* Recoding setsize to have actual values.
	 RECODE setsize (1=3) (2=6) (3=9).
* Labeling new variables not already labeled.
	 VARIABLE LABELS rt_ms 'RT in Milliseconds'
			               p_err 'Percent Errors'.
* Old condition responses have already been dropped.
* Variable transformation in stacked dataset.
* Creating natural log transform of RT.
		COMPUTE lg_rt = LN(rt_ms).
* Creating z-scored version of log RT and errors.
		COMPUTE z_lg_rt = ((lg_rt - 6.7317470) / 0.2412115).
		COMPUTE z_p_err = ((p_err - 0.1719970) / 0.1486222).
* Centering age at 75.
		COMPUTE c_age = age - 75.
* Centering setsize at 6.
		COMPUTE c_size = setsize - 6.
* Centering target letter.
		COMPUTE c_targ = target - 1.
* Labeling new variables.
	 VARIABLE LABELS lg_rt 'Natural Log RT in Milliseconds'
			    z_lg_rt 'Z-Scored Natural Log RT in Milliseconds'
			    z_p_err 'Z-Scored Percent Errors'
			    c_age 'Centered Age (0=75)'
			    c_size 'Centered Set Size (0=6)'
       c_targ 'Centered Target Letter (0=L, 1=R)'.

* Creating double-stacked dataset for multivariate analysis.
* Define new SPSS dataset called 'Ex2_2'.
	VARSTOCASES  
		/MAKE y_raw FROM lg_rt p_err
 	/MAKE y_SD  FROM z_lg_rt z_p_err
 	/INDEX = DV "Which Outcome Variable (1=RT, 2=Error)"(2) 
 	/KEEP = ALL.
* Creating dummy variables for DV.
 	RECODE DV (1=1) (2=0) INTO DV1.
 	RECODE DV (1=0) (2=1) INTO DV2.
* Labeling new variables.
	VARIABLE LABELS
		y_raw 'Raw-Score Multivariate Outcome'
		y_SD 'Z-Score Multivariate Outcome'
		dv1 'Response Time (0=no, 1=yes)'
		dv2 'Percent Error (0=no, 1=yes)'.
* Rename and save file.
	 DATASET NAME Ex2_2 WINDOW=FRONT.
  SAVE OUTFILE = 'filepath\Ex2_2.sav'.


* Additional MIXED syntax commands below:
BY defines categorical variables (nesting variables and DV)
FIXED defines fixed effects
	/ NOINT removes intercept (when using dv1 and dv2 instead)
RANDOM lists random effects
	/ SUBJECT(ID) defines nesting structure for level 3
	  COVTYPE(UN) specifies unstructured matrix (all variances &
			  covariances of random effects)
REPEATED lists repeated effects
	/ SUBJECT(target*setsize*ID) defines nesting structure for level 2
	  COVTYPE(UN) specifies unstructured matrix (all variances &
			  covariances of residuals) .
	
* Example 2 Multilevel Models.

DATASET ACTIVATE Ex2_2 WINDOW=FRONT.

TITLE 'SPSS Model 2.1: Empty Model'.
MIXED y_raw BY ID target setsize DV WITH dv1 dv2
  	/FIXED  = dv1 dv2 | NOINT
  	/METHOD = ML
  	/PRINT  = SOLUTION TESTCOV
 	 /RANDOM = DV1 DV2 | SUBJECT(ID) COVTYPE(UN) 
  	/REPEATED = DV | SUBJECT(target*setsize*ID) COVTYPE(UN).

TITLE 'SPSS Model 2.2: Main Effects Model'.
MIXED y_raw BY ID target setsize DV WITH dv1 dv2 c_size c_targ c_age
  	/FIXED = dv1 dv1*c_size dv1*c_targ dv1*c_age 
		          dv2 dv2*c_size dv2*c_targ dv2*c_age | NOINT
  	/METHOD = ML
  	/PRINT  = SOLUTION TESTCOV
 	 /RANDOM = dv1 dv2 dv1*c_size dv2*c_size dv1*c_targ dv2*c_targ | SUBJECT(ID) COVTYPE(UN) 
	  /REPEATED = DV | SUBJECT(target*setsize*ID) COVTYPE(UN).

TITLE 'SPSS Model 2.3: All Interactions Model'.
MIXED y_raw BY ID target setsize DV WITH dv1 dv2 c_size c_targ c_age
  	/FIXED = dv1 dv1*c_size dv1*c_targ dv1*c_age 
		          dv1*c_size*c_targ dv1*c_age*c_size dv1*c_age*c_targ
		          dv1*c_age*c_size*c_targ
		          dv2 dv2*c_size dv2*c_targ dv2*c_age
		          dv2*c_size*c_targ dv2*c_age*c_size dv2*c_age*c_targ
		          dv2*c_age*c_size*c_targ | NOINT
  	/METHOD = ML
  	/PRINT  = SOLUTION TESTCOV
 	 /RANDOM = dv1 dv2 dv1*c_size dv2*c_size dv1*c_targ dv2*c_targ | SUBJECT(ID) COVTYPE(UN) 
	  /REPEATED = DV | SUBJECT(target*setsize*ID) COVTYPE(UN).
		
TITLE 'SPSS Model 2.3: Significant Interactions Only Model'.
MIXED y_raw BY ID target setsize DV WITH dv1 dv2 c_size c_targ c_age
  	/FIXED = dv1 dv1*c_size dv1*c_targ dv1*c_age 
		          dv1*c_size*c_targ dv1*c_age*c_size
		          dv2 dv2*c_size dv2*c_targ dv2*c_age | NOINT
  	/METHOD = ML
  	/PRINT  = SOLUTION TESTCOV
 	 /RANDOM = dv1 dv2 dv1*c_size dv2*c_size dv1*c_targ dv2*c_targ | SUBJECT(ID) COVTYPE(UN) 
  	/REPEATED = DV | SUBJECT(target*setsize*ID) COVTYPE(UN).

TITLE 'SPSS Re-Parameterized Model 2.3: Standardized Response Variables'.
MIXED y_SD BY ID target setsize DV WITH dv1 dv2 c_size c_targ c_age
  	/FIXED = c_size c_targ c_age c_size*c_targ c_age*c_size
		          dv2 dv2*c_size dv2*c_targ dv2*c_age 
		          dv2*c_size*c_targ dv2*c_age*c_size
  	/METHOD = ML
  	/PRINT  = SOLUTION TESTCOV
 	 /RANDOM = dv1 dv2 dv1*c_size dv2*c_size dv1*c_targ dv2*c_targ	| SUBJECT(ID) COVTYPE(UN) 
  	/REPEATED = DV | SUBJECT(target*setsize*ID) COVTYPE(UN).	   


